@@ -6,6 +6,8 @@ use OIDC::Lite::Server::GrantHandler::AuthorizationCode;
 use OAuth::Lite2::Server::GrantHandler::Password;
 use OAuth::Lite2::Server::GrantHandler::RefreshToken;
 use OAuth::Lite2::Server::GrantHandler::ClientCredentials;
+use OAuth::Lite2::Server::GrantHandler::GroupingRefreshToken;
+use OAuth::Lite2::Server::GrantHandler::ServerState;
 
 my %HANDLERS;
 
@@ -22,6 +24,10 @@ __PACKAGE__->add_handler( 'refresh_token' =>
     OAuth::Lite2::Server::GrantHandler::RefreshToken->new );
 __PACKAGE__->add_handler( 'client_credentials' =>
     OAuth::Lite2::Server::GrantHandler::ClientCredentials->new );
+__PACKAGE__->add_handler( 'grouping_refresh_token' =>
+    OAuth::Lite2::Server::GrantHandler::GroupingRefreshToken->new );
+__PACKAGE__->add_handler( 'server_state' =>
+    OAuth::Lite2::Server::GrantHandler::ServerState->new );
 
 #__PACKAGE__->add_handler( 'assertion' => );
 #__PACKAGE__->add_handler( 'none' => );
@@ -61,6 +67,8 @@ L<OIDC::Lite::Server::GrantHandler::AuthorizationCode>
 L<OAuth::Lite2::Server::GrantHandler::ClientCredentials>
 L<OAuth::Lite2::Server::GrantHandler::Password>
 L<OAuth::Lite2::Server::GrantHandler::RefreshToken>
+L<OAuth::Lite2::Server::GrantHandler::GroupingRefreshToken>
+L<OAuth::Lite2::Server::GrantHandler::ServerState>
 
 =head1 AUTHOR
 
